// MIT License

// Copyright (c) 2020 Tree Xie

// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:

// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.

// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

package util

import (
	"sync"
	"testing"

	"github.com/stretchr/testify/assert"
	"github.com/vicanso/hes"
)

func TestMapDelete(t *testing.T) {
	assert := assert.New(t)
	m := &sync.Map{}
	m.Store("a", "1")
	m.Store("b", "2")

	result := MapDelete(m, func(key string) bool {
		return key == "a"
	})
	assert.Equal(1, len(result))

	_, ok := m.Load("a")
	assert.False(ok)
	value, ok := m.Load("b")
	assert.True(ok)
	assert.Equal("2", value)

}

func TestNewError(t *testing.T) {
	assert := assert.New(t)
	message := "error"
	statusCode := 400
	err := NewError(message, statusCode)

	assert.NotNil(err)
	he, ok := err.(*hes.Error)
	assert.True(ok)
	assert.Equal(statusCode, he.StatusCode)
	assert.Equal(message, he.Message)
	assert.Equal(errCategory, he.Category)
}
